@@ -18,11 +18,7 @@ namespace
     template<typename T>
     QSet<T> listToSet(const QList<T> &list)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        return list.toSet();
-#else
         return {list.cbegin(), list.cend()};
-#endif
     }
 }
 
